from setuptools import setup

setup(name='vapl_interpreter',
      version='0.1.1',
      description='An interpreter for VAPL',
      url='https://replit.com/@WWWtheW/vaplinterpreter#README.md',
      author='WWWtheW',
      author_email='dontemailme@heheehheeeeeeeeeeeeeheehehehehe.com',
      license='MIT',
      packages=['vapl_interpreter'],
      zip_safe=False)